Callback when player moves. (if playAs is null, this function is called for both players moves, otherwise for only for the playAs). E.g. if the player is playing as white, this method receives callbacks only for white's moves.
Define which side the player has to play, black or white and the other pieces will be no longer be interactive for the player. Keep this null when both players are playing in same device (i.e. in case of offline match).
If true, arbiter will spectate the game and check for checkmate or stalemate.
If false, the game will be played without arbiter's intervention.
This is useful for testing purposes or if you want to handle game logic manually.